# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/ebuy/sample/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/ebuy/sample/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Ebuy\\Sample\\": "packages/ebuy/sample/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Ebuy\Sample\Providers\SampleServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Sample'  => Ebuy\Sample\Facades\Sample::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Ebuy\\SampleTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Ebuy\Sample\Providers\SampleServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Ebuy\Sample\Providers\SampleServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Ebuy\Sample\Providers\SampleServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/sample/{modulename}

**User**

    http://path-to-route-folder/user/sample/{modulename}

**Public**

    http://path-to-route-folder/samples


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/sample/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/sample/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/sample/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/sample/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/sample/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/sample/{modulename}/{slug}
    METHOD: GET