<?php

namespace Ebuy\Sample\Policies;

use Litepie\User\Contracts\UserPolicy;
use Ebuy\Sample\Models\Sample;

class SamplePolicy
{

    /**
     * Determine if the given user can view the sample.
     *
     * @param UserPolicy $user
     * @param Sample $sample
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sample $sample)
    {
        if ($user->canDo('sample.sample.view') && $user->isAdmin()) {
            return true;
        }

        return $sample->user_id == user_id() && $sample->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sample.
     *
     * @param UserPolicy $user
     * @param Sample $sample
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sample.sample.create');
    }

    /**
     * Determine if the given user can update the given sample.
     *
     * @param UserPolicy $user
     * @param Sample $sample
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sample $sample)
    {
        if ($user->canDo('sample.sample.edit') && $user->isAdmin()) {
            return true;
        }

        return $sample->user_id == user_id() && $sample->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sample.
     *
     * @param UserPolicy $user
     * @param Sample $sample
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sample $sample)
    {
        return $sample->user_id == user_id() && $sample->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sample.
     *
     * @param UserPolicy $user
     * @param Sample $sample
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sample $sample)
    {
        if ($user->canDo('sample.sample.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sample.
     *
     * @param UserPolicy $user
     * @param Sample $sample
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sample $sample)
    {
        if ($user->canDo('sample.sample.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
